@@ -10,6 +10,8 @@ COOL_DOWN = 60 * 5  # 5 minutes before retrying
 @task
 def send_tracking_to_backend(backend_name, **kwargs):
     backend = get_backend(backend_name)
+    if not backend:
+        return
     return backend.send(**kwargs)
 
 
@@ -18,6 +20,8 @@ def send_tracking_to_backends(backend_names, **kwargs):
     results = list()
     for backend_name in backend_names:
         backend = get_backend(backend_name)
+        if not backend:
+            continue
         try:
             results.append(backend.send(**kwargs))
         except:
